/********************************************************************************
** Form generated from reading UI file 'kmahjonggtilesetselector.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KMAHJONGGTILESETSELECTOR_H
#define UI_KMAHJONGGTILESETSELECTOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KMahjonggTilesetSelector
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QListWidget *tilesetList;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout1;
    QLabel *tilesetPreview;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *labelAuthor;
    QLabel *tilesetAuthor;
    QLabel *labelContact;
    QLabel *tilesetContact;
    QLabel *labelDescription;
    QLabel *tilesetDescription;
    QLabel *label;
    QLabel *tilesetVersion;
    QLabel *label1;
    QLabel *tilesetWebsite;
    QLabel *label2;
    QLabel *tilesetCopyright;
    QLabel *label3;
    QLabel *tilesetLicense;
    QLineEdit *kcfg_TileSet;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *KMahjonggTilesetSelector)
    {
        if (KMahjonggTilesetSelector->objectName().isEmpty())
            KMahjonggTilesetSelector->setObjectName("KMahjonggTilesetSelector");
        KMahjonggTilesetSelector->resize(497, 446);
        KMahjonggTilesetSelector->setMaximumSize(QSize(800, 600));
        vboxLayout = new QVBoxLayout(KMahjonggTilesetSelector);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        tilesetList = new QListWidget(KMahjonggTilesetSelector);
        tilesetList->setObjectName("tilesetList");
        tilesetList->setMinimumSize(QSize(120, 0));

        hboxLayout->addWidget(tilesetList);

        groupBox_2 = new QGroupBox(KMahjonggTilesetSelector);
        groupBox_2->setObjectName("groupBox_2");
        vboxLayout1 = new QVBoxLayout(groupBox_2);
        vboxLayout1->setObjectName("vboxLayout1");
        tilesetPreview = new QLabel(groupBox_2);
        tilesetPreview->setObjectName("tilesetPreview");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tilesetPreview->sizePolicy().hasHeightForWidth());
        tilesetPreview->setSizePolicy(sizePolicy);
        tilesetPreview->setMinimumSize(QSize(120, 160));

        vboxLayout1->addWidget(tilesetPreview);


        hboxLayout->addWidget(groupBox_2);


        vboxLayout->addLayout(hboxLayout);

        groupBox = new QGroupBox(KMahjonggTilesetSelector);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        labelAuthor = new QLabel(groupBox);
        labelAuthor->setObjectName("labelAuthor");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelAuthor);

        tilesetAuthor = new QLabel(groupBox);
        tilesetAuthor->setObjectName("tilesetAuthor");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, tilesetAuthor);

        labelContact = new QLabel(groupBox);
        labelContact->setObjectName("labelContact");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, labelContact);

        tilesetContact = new QLabel(groupBox);
        tilesetContact->setObjectName("tilesetContact");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, tilesetContact);

        labelDescription = new QLabel(groupBox);
        labelDescription->setObjectName("labelDescription");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, labelDescription);

        tilesetDescription = new QLabel(groupBox);
        tilesetDescription->setObjectName("tilesetDescription");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, tilesetDescription);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label);

        tilesetVersion = new QLabel(groupBox);
        tilesetVersion->setObjectName("tilesetVersion");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, tilesetVersion);

        label1 = new QLabel(groupBox);
        label1->setObjectName("label1");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label1);

        tilesetWebsite = new QLabel(groupBox);
        tilesetWebsite->setObjectName("tilesetWebsite");
        tilesetWebsite->setOpenExternalLinks(false);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, tilesetWebsite);

        label2 = new QLabel(groupBox);
        label2->setObjectName("label2");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label2);

        tilesetCopyright = new QLabel(groupBox);
        tilesetCopyright->setObjectName("tilesetCopyright");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, tilesetCopyright);

        label3 = new QLabel(groupBox);
        label3->setObjectName("label3");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label3);

        tilesetLicense = new QLabel(groupBox);
        tilesetLicense->setObjectName("tilesetLicense");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, tilesetLicense);


        vboxLayout->addWidget(groupBox);

        kcfg_TileSet = new QLineEdit(KMahjonggTilesetSelector);
        kcfg_TileSet->setObjectName("kcfg_TileSet");
        kcfg_TileSet->setEnabled(false);
        kcfg_TileSet->setFrame(false);
        kcfg_TileSet->setReadOnly(false);

        vboxLayout->addWidget(kcfg_TileSet);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(KMahjonggTilesetSelector);

        QMetaObject::connectSlotsByName(KMahjonggTilesetSelector);
    } // setupUi

    void retranslateUi(QWidget *KMahjonggTilesetSelector)
    {
        groupBox_2->setTitle(tr2i18n("Preview", nullptr));
        groupBox->setTitle(tr2i18n("Properties", nullptr));
        labelAuthor->setText(tr2i18n("Author:", nullptr));
        labelContact->setText(tr2i18n("Contact:", nullptr));
        labelDescription->setText(tr2i18n("Description:", nullptr));
        label->setText(tr2i18n("Version:", nullptr));
        label1->setText(tr2i18n("Website:", nullptr));
        label2->setText(tr2i18n("Copyright:", nullptr));
        label3->setText(tr2i18n("License:", nullptr));
        (void)KMahjonggTilesetSelector;
    } // retranslateUi

};

namespace Ui {
    class KMahjonggTilesetSelector: public Ui_KMahjonggTilesetSelector {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KMAHJONGGTILESETSELECTOR_H

